==> proc-10.1.32.tar.gz: proc/js/proc-field.js <==
/**
 * @file
 * Helper for entity reference proc field.
 */
(function($, Drupal, drupalSettings, once) {
  Drupal.behaviors.ProcBehavior = {
    attach(context, settings) {
      once('proc-decrypt', 'html', context).forEach(function(element) {

        const procFieldElements = document.querySelectorAll('[proc="true"]');
        const procFields = [];

        procFieldElements.forEach((fieldElement, fieldElementIndex) => {
          procFields.push(
            fieldElement.attributes.name.value.substring(
              0,
              fieldElement.attributes.name.value.indexOf('['),
            ),
          );
        });

        // Leave encryption checkbox disabled until there is a value in the field.
        procFields.map((fieldName, fieldIndex) => {
          const encryptCheckbox = document.querySelector(
            `[id="encrypt-checkbox-${fieldName}"]`,
          );
          const input = document.querySelector(`[name^="${fieldName}"]`);
          if (input.value == '') {
            encryptCheckbox.disabled = true;
          }
          else {
            encryptCheckbox.disabled = false;
          }
        });

        if (drupalSettings.proc && drupalSettings.proc.submit_element_id) {
          const submitIdsCsv = drupalSettings.proc.submit_element_id.replace(/ /g, '');
          const submitIds = submitIdsCsv.split(',');
          let submitElements = [];
          submitIds.map((submitId, submitIndex) => {
            submitElements.push(document.getElementById(submitId));
          });

          procFields.map((fieldName, fieldIndex) => {
            let input = document.querySelector(`[name^="${fieldName}"]`);
            input.addEventListener("input", updateValue);

            function updateValue(e) {
              let encryptCheckbox = document.querySelector(`[id="encrypt-checkbox-${fieldName}"]`);
              if (e.target.value == '') {
                encryptCheckbox.disabled = true;
                // If current field is empty and all other fields are empty:
                let empty = 1;
                procFields.map((innerFieldName, innerFieldIndex) => {
                  let innerInput = document.querySelector(`[name^="${innerFieldName}"]`);
                  // Check if encryption checkbox is checked.
                  let innerCheckbox = document.querySelector(`[id="encrypt-checkbox-${innerFieldName}"]`);
                  if (innerInput.value != '' && !innerCheckbox.checked) {
                    empty = 0;
                  }
                });
                if (empty == 1) {
                  // Enable submit when all fields are empty:
                  submitElements.map((submitElement, submitIndex) => {
                    submitElement.disabled = false;
                    encryptCheckbox.disabled = true;
                  });
                }
              }
              else {
                // If there is some text in the field, enable the encryption checkbox:
                // let encryptCheckbox = document.querySelector(`[id="encrypt-checkbox-${fieldName}"]`);
                encryptCheckbox.disabled = false;
              }
            }

            const field = document.querySelector(`[name^="${fieldName}"]`);
            field.oninput = () => {
              submitElements.map((submitElement, submitIndex) => {
                if (submitElement.disabled === false && field.value != '') {
                  // Disable submit when something is typed in for encryption:
                  submitElement.disabled = true;
                }
              });
            };
            const encryptCheckbox = document.querySelector(
              `[id="encrypt-checkbox-${fieldName}"]`,
            );
            if (encryptCheckbox) {
              encryptCheckbox.addEventListener("input", updateCheckboxValue);

              function updateCheckboxValue(checkBoxEvent) {
                if (checkBoxEvent.target.checked) {
                  // If for all other checkboxes are also checked:
                  let checked = 1;
                  procFields.map((innerFieldName, innerFieldIndex) => {

                    let innerCheckbox = document.querySelector(`[id="encrypt-checkbox-${innerFieldName}"]`);
                    if (!innerCheckbox.checked) {
                      let innerInput = document.querySelector(`[name^="${innerFieldName}"]`);
                      checked = 0;
                      if (innerInput.value == '') {
                        checked = 1;
                      }
                    }
                  });
                  if (checked == 1) {
                    // Enable submit when all checkboxes are checked:
                    submitElements.map((submitElement, submitIndex) => {
                      submitElement.disabled = false;
                    });
                  }
                }
                else {
                  submitElements.map((submitElement, submitIndex) => {
                    if (submitElement.disabled === false) {
                      submitElement.disabled = true;
                    }
                  });
                }
              }
            }
          });
        }
      });
    },
  };
})(jQuery, Drupal, drupalSettings, once);

==> proc-10.1.33.tar.gz: proc/js/proc-field.js <==
/**
 * @file
 * Helper for entity reference proc field.
 */
(function($, Drupal, drupalSettings, once) {
  Drupal.behaviors.ProcBehavior = {
    attach(context, settings) {
      once('proc-decrypt', 'html', context).forEach(function(element) {
        // Get elements with 'proc' attribute set to 'true' that are not autocomplete.
        const procFieldElements = document.querySelectorAll('[proc="true"]:not(.form-autocomplete)');
        const procFields = [];

        procFieldElements.forEach((fieldElement, fieldElementIndex) => {
          procFields.push(
            fieldElement.attributes.name.value.substring(
              0,
              fieldElement.attributes.name.value.indexOf('['),
            ),
          );
        });

        // Leave encryption checkbox disabled until there is a value in the field.
        procFields.map((fieldName, fieldIndex) => {
          const encryptCheckbox = document.querySelector(
            `[id="encrypt-checkbox-${fieldName}"]`,
          );
          const input = document.querySelector(`[name^="${fieldName}"]`);
          if (input.value == '') {
            encryptCheckbox.disabled = true;
          }
          else {
            encryptCheckbox.disabled = false;
          }
        });

        if (drupalSettings.proc && drupalSettings.proc.submit_element_id) {
          const submitIdsCsv = drupalSettings.proc.submit_element_id.replace(/ /g, '');
          const submitIds = submitIdsCsv.split(',');
          let submitElements = [];
          submitIds.map((submitId, submitIndex) => {
            submitElements.push(document.getElementById(submitId));
          });

          procFields.map((fieldName, fieldIndex) => {
            let input = document.querySelector(`[name^="${fieldName}"]`);
            input.addEventListener("input", updateValue);

            function updateValue(e) {
              let encryptCheckbox = document.querySelector(`[id="encrypt-checkbox-${fieldName}"]`);
              if (e.target.value == '') {
                encryptCheckbox.disabled = true;
                // If current field is empty and all other fields are empty:
                let empty = 1;
                procFields.map((innerFieldName, innerFieldIndex) => {
                  let innerInput = document.querySelector(`[name^="${innerFieldName}"]`);
                  // Check if encryption checkbox is checked.
                  let innerCheckbox = document.querySelector(`[id="encrypt-checkbox-${innerFieldName}"]`);
                  if (innerInput.value != '' && !innerCheckbox.checked) {
                    empty = 0;
                  }
                });
                if (empty == 1) {
                  // Enable submit when all fields are empty:
                  submitElements.map((submitElement, submitIndex) => {
                    submitElement.disabled = false;
                    encryptCheckbox.disabled = true;
                  });
                }
              }
              else {
                // If there is some text in the field, enable the encryption checkbox:
                // let encryptCheckbox = document.querySelector(`[id="encrypt-checkbox-${fieldName}"]`);
                encryptCheckbox.disabled = false;
              }
            }

            const field = document.querySelector(`[name^="${fieldName}"]`);
            field.oninput = () => {
              submitElements.map((submitElement, submitIndex) => {
                if (submitElement.disabled === false && field.value != '') {
                  // Disable submit when something is typed in for encryption:
                  submitElement.disabled = true;
                }
              });
            };
            const encryptCheckbox = document.querySelector(
              `[id="encrypt-checkbox-${fieldName}"]`,
            );
            if (encryptCheckbox) {
              encryptCheckbox.addEventListener("input", updateCheckboxValue);

              function updateCheckboxValue(checkBoxEvent) {
                if (checkBoxEvent.target.checked) {
                  // If for all other checkboxes are also checked:
                  let checked = 1;
                  procFields.map((innerFieldName, innerFieldIndex) => {

                    let innerCheckbox = document.querySelector(`[id="encrypt-checkbox-${innerFieldName}"]`);
                    if (!innerCheckbox.checked) {
                      let innerInput = document.querySelector(`[name^="${innerFieldName}"]`);
                      checked = 0;
                      if (innerInput.value == '') {
                        checked = 1;
                      }
                    }
                  });
                  if (checked == 1) {
                    // Enable submit when all checkboxes are checked:
                    submitElements.map((submitElement, submitIndex) => {
                      submitElement.disabled = false;
                    });
                  }
                }
                else {
                  submitElements.map((submitElement, submitIndex) => {
                    if (submitElement.disabled === false) {
                      submitElement.disabled = true;
                    }
                  });
                }
              }
            }
          });
        }
      });
    },
  };
})(jQuery, Drupal, drupalSettings, once);
